@@ -339,18 +339,17 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
       if( currentMatchContext.size()) {
         
         int bestQuality = 0;
-        foreach(IndexedType type, currentMatchContext) {
-        
-        Cpp::TypeConversion conv(model->currentTopContext().data());
- 
-        AbstractType::Ptr ownType = effectiveType(dec);
-        
-        bool fromLValue = (bool)ownType.cast<ReferenceType>() || (!dynamic_cast<AbstractFunctionDeclaration*>(dec) && dec->kind() == Declaration::Instance);
-        
-        ///@todo fill the lvalue-ness correctly
-        int q = ( conv.implicitConversion( completionContext()->applyPointerConversionForMatching(ownType->indexed(), fromLValue), type, fromLValue )  * 10 ) / Cpp::MaximumConversionResult;
-        if(q > bestQuality)
-          bestQuality = q;
+        foreach(const IndexedType& type, currentMatchContext) {
+          Cpp::TypeConversion conv(model->currentTopContext().data());
+  
+          AbstractType::Ptr ownType = effectiveType(dec);
+          
+          bool fromLValue = (bool)ownType.cast<ReferenceType>() || (!dynamic_cast<AbstractFunctionDeclaration*>(dec) && dec->kind() == Declaration::Instance);
+          
+          ///@todo fill the lvalue-ness correctly
+          int q = ( conv.implicitConversion( completionContext()->applyPointerConversionForMatching(ownType->indexed(), fromLValue), type, fromLValue )  * 10 ) / Cpp::MaximumConversionResult;
+          if(q > bestQuality)
+            bestQuality = q;
         }
         
         return QVariant(bestQuality);
@@ -606,14 +605,13 @@ QVariant TypeConversionCompletionItem::data(const QModelIndex& index, int role,
       }
       
       if( currentMatchContext.size() ) {
+        int bestQuality = 0;
         
-          int bestQuality = 0;
-          
-          foreach(IndexedType type, currentMatchContext) {
+        foreach(const IndexedType& type, currentMatchContext) {
           Cpp::TypeConversion conv(model->currentTopContext().data());
 
           ///@todo Think about lvalue-ness
-          foreach(IndexedType ownType, typeForArgumentMatching()) {
+          foreach(const IndexedType& ownType, typeForArgumentMatching()) {
             int quality = ( conv.implicitConversion( completionContext->applyPointerConversionForMatching(ownType, false), type, false )  * 10 ) / Cpp::MaximumConversionResult;
             if(quality > bestQuality)
               bestQuality = quality;
