@@ -32,7 +32,6 @@
 
 #include <language/duchain/duchainpointer.h>
 #include <contextbuilder.h>
-#include <language/duchain/indexedstring.h>
 #include <qwaitcondition.h>
 #include "includepathcomputer.h"
 #include <parsesession.h>
@@ -261,11 +260,5 @@ private:
     int m_priority;
 };
 
-struct UrlParseLock {
-  UrlParseLock(IndexedString url);
-  ~UrlParseLock();
-  IndexedString m_url;
-};
-
 #endif
 
