@@ -92,6 +92,9 @@ private slots:
   void testMacroExpansionRanges();
   void testEmptyMacroArguments();
   void testMacrosInCodeCompletion();
+  void testTimeMacro();
+  void testDateMacro();
+  void testFileMacro();
   void testPreprocessor();
   void testNaiveMatching();
   void testFriendVisibility();
@@ -110,6 +113,7 @@ private slots:
   void testSubClassVisibility();
   void testSignalSlotCompletion();
   void testStringProblem();
+  void testArgumentList();
 
 public:
   enum DumpArea {
