@@ -149,6 +149,11 @@ QList<ProjectFolderItem*> CustomMakeManager::parse(KDevelop::ProjectFolderItem *
         
         if ( fileInfo.isDir() )
         {
+            //TODO: make filtering generic
+            if ( fileName == ".svn" || fileName == "CVS" || fileName == ".git" )
+            {
+                continue;
+            }
 //             KDevelop::ProjectFolderItem *cmfi= new KDevelop::ProjectFolderItem(
 //                     item->project(), KUrl( fileInfo.absoluteFilePath() ), item );
             // TODO more faster algorithm. should determine whether this directory
@@ -183,7 +188,7 @@ QList<ProjectFolderItem*> CustomMakeManager::parse(KDevelop::ProjectFolderItem *
 //     if( makefileUrl.isValid() )
 //     {
 //         QStringList targetlist = this->parseCustomMakeFile( makefileUrl );
-//         foreach( QString target, targetlist )
+//         foreach(const  QString& target, targetlist )
 //         {
 //             new CustomMakeTargetItem( item->project(), target, item );
 // //             d->m_testItems.append( targetItem ); // debug
@@ -243,6 +248,7 @@ bool CustomMakeManager::renameFolder(KDevelop::ProjectFolderItem* oldFolder, con
 /////////////////////////////////////////////////////////////////////////////
 // private slots
 
+///TODO: move to background thread, probably best would be to use a proper ParseJob
 QStringList CustomMakeManager::parseCustomMakeFile( const KUrl &makefile )
 {
     if( !makefile.isValid() )
